The `Python` module `cbdevtools`
================================


> **I beg your pardon for my english...**
>
> English is not my native language, so be nice if you notice misunderstandings, misspellings, or grammatical errors in my documents and codes.


About `cbdevtools`
-----------------

This project is a "Common Box of Dev Tools". It proposes small scripts taht can be helpful, at least to the author of this package. :-) 


????
----



<!-- :tutorial-START: -->
<!-- :tutorial-END: -->


<!-- :version-START: -->
<!-- :version-END: -->
